from base import BaseParser
from bind9 import BIND9Parser
from exports import ExportsParser
from ini import IniFileParser
from iptables import IPTablesParser
from jsonparser import JsonParser
from nginx import NginxParser
from nsd import NSDParser
from ssv import SSVParser
from squid import SquidParser
from crontab import CrontabParser

__all__ = [
    'BaseParser',
    'BIND9Parser',
    'CrontabParser',
    'ExportsParser',
    'IniFileParser',
    'IPTablesParser',
    'JsonParser',
    'NginxParser',
    'NSDParser',
    'SSVParser',
    'SquidParser',
]



from reconfigure.configs.base import Reconfig
from reconfigure.parsers import NginxParser
from reconfigure.builders import BoundBuilder
from reconfigure.items.dhcpd import DHCPDData


class DHCPDConfig (Reconfig):
    """
    ``DHCPD``
    """
    def __init__(self, **kwargs):
        k = {
            'parser': NginxParser(),
            'builder': BoundBuilder(DHCPDData),
        }
        k.update(kwargs)
        Reconfig.__init__(self, **k)



"""
Builders are used to convert Node Tree to Data Tree
"""

from base import BaseBuilder
from bound import BoundBuilder
#from nginx import NginxBuilder
#from crontab import CrontabBuilder


__all__ = [
    'BaseBuilder',
    'BoundBuilder',
    #'NginxBuilder',
    #'CrontabBuilder',
]



"""
Configs are ready-to-use objects that link together Parsers, Includers and Builders to provide direct conversion between config files and Data tree.
"""

from base import Reconfig
from ajenti import AjentiConfig
from bind9 import BIND9Config
from crontab import CrontabConfig
from ctdb import CTDBConfig, CTDBNodesConfig, CTDBPublicAddressesConfig
from dhcpd import DHCPDConfig
from exports import ExportsConfig
from fstab import FSTabConfig
from group import GroupConfig
from hosts import HostsConfig
from iptables import IPTablesConfig
from netatalk import NetatalkConfig
from nsd import NSDConfig
from passwd import PasswdConfig
from resolv import ResolvConfig
from samba import SambaConfig
from squid import SquidConfig
from supervisor import SupervisorConfig


__all__ = [
    'Reconfig',
    'AjentiConfig',
    'BIND9Config',
    'CrontabConfig',
    'CTDBConfig',
    'CTDBNodesConfig',
    'CTDBPublicAddressesConfig',
    'DHCPDConfig',
    'ExportsConfig',
    'FSTabConfig',
    'GroupConfig',
    'HostsConfig',
    'IPTablesConfig',
    'NetatalkConfig',
    'NSDConfig',
    'PasswdConfig',
    'ResolvConfig',
    'SambaConfig',
    'SquidConfig',
    'SupervisorConfig',
]



from base import BaseIncluder
from auto import AutoIncluder
from bind9 import BIND9Includer
from nginx import NginxIncluder
from supervisor import SupervisorIncluder


__all__ = [
    'BaseIncluder',
    'AutoIncluder',
    'BIND9Includer',
    'NginxIncluder',
    'SupervisorIncluder',
]
